#using <mscorlib.dll>

using namespace System;
using namespace System::ComponentModel;
using namespace System::Diagnostics;
using namespace System::IO;
using namespace WebCab::Lib::Util::Example;

using namespace WebCab::Libraries::Statistics::Hypothesis;

template< class T >
T managed2DimArray( T* ca, int dim1, int dim2 ) __gc[,] {
   T a __gc[,] = new T __gc[dim1, dim2];
   for ( int i = 0; i < dim1; i ++ ) {
      for ( int j = 0; j < dim2; j ++ ) {
         a[i, j] = ca[ i * dim2 + j ];
      }
   }
   return a;
}

static double double2Double( double d ) {
   if ( Double::IsNaN( d ) ) return d;
   if ( Double::IsNegativeInfinity( d ) ) return d;
   if ( Double::IsPositiveInfinity( d ) ) return d;
   if ( d == Double::MinValue ) return d;
   if ( d == Double::MaxValue ) return d;
   double frac = d - ( int )d;
   double frac4 = ( int )( frac * 10000 ) / 10000.0;
   return ( int )d + frac4;
}

static void displayArray( double a __gc[], StreamWriter* streamWriter ) {
   for ( int i = 0; i < a->Length; i ++ ) {
      streamWriter->Write( double2Double( a[ i ] ) );
      streamWriter->Write( ", " );
   }
   streamWriter->WriteLine( " " );
}

int main() {
   Process* myProcess;
   myProcess = new Process ();
   myProcess->StartInfo->FileName = "more.com";
   myProcess->StartInfo->UseShellExecute = false;
   myProcess->StartInfo->RedirectStandardInput = true;
   myProcess->Start();
   StreamWriter* streamWriter = myProcess->StandardInput;
   streamWriter->AutoFlush = true;
   // used components
   NormalHypothesis* instanceOfNormalHypothesis = new NormalHypothesis;
   //
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "                   ###########################################" );
   streamWriter->WriteLine( "                   # NormalHypothesis Console Client Example #" );
   streamWriter->WriteLine( "                   ###########################################" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " --------" );
   streamWriter->WriteLine( " Overview" );
   streamWriter->WriteLine( " --------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    Within       this  client  we  illustrate  the  application  of  the" );
   streamWriter->WriteLine( "    NormalHypothesis class." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Press ENTER or SPACE to scroll down." );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Hypothesis testing for the difference between means +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    meansDifference( double mean1," );
   streamWriter->WriteLine( "                     double mean2," );
   streamWriter->WriteLine( "                     double claimedDifference," );
   streamWriter->WriteLine( "                     double standardDeviation1," );
   streamWriter->WriteLine( "                     double standardDeviation2," );
   streamWriter->WriteLine( "                     int size1," );
   streamWriter->WriteLine( "                     int size2," );
   streamWriter->WriteLine( "                     double significanceLevel )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we preformed the hypothesis test where the null  hypothesis  is" );
   streamWriter->WriteLine( "     that the difference between the means  is  5,  and  the  alternative" );
   streamWriter->WriteLine( "     hypothesis is that they are not 5, to a level of  confidence  of  99" );
   streamWriter->WriteLine( "     percent." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    mean1 = 165" );
   streamWriter->WriteLine( "    mean2 = 160" );
   streamWriter->WriteLine( "    claimedDifference = 5" );
   streamWriter->WriteLine( "    standardDeviation1 = 3" );
   streamWriter->WriteLine( "    standardDeviation2 = 4" );
   streamWriter->WriteLine( "    size1 = 15" );
   streamWriter->WriteLine( "    size2 = 13" );
   streamWriter->WriteLine( "    significanceLevel = 99" );
   // Performs hypothesis testing for the difference between means.
   bool diffMeans1;
   {
   diffMeans1 = instanceOfNormalHypothesis->MeansDifference( 
      165.0, // mean1
      160.0, // mean2
      5.0, // claimedDifference
      3.0, // standardDeviation1
      4.0, // standardDeviation2
      15, // size1
      13, // size2
      99.0 // significanceLevel
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The statement that the null hypothesis is be rejected is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( diffMeans1 );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Hypothesis Testing about the mean +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    meanTest( double claimedMean," );
   streamWriter->WriteLine( "              double mean," );
   streamWriter->WriteLine( "              double standardDeviation," );
   streamWriter->WriteLine( "              int sampleSize," );
   streamWriter->WriteLine( "              double significanceLevel )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we test the hypothesis to  a  95  percentage  confidence  level" );
   streamWriter->WriteLine( "     where the null hypothesis is that the  mean  of  the  population  is" );
   streamWriter->WriteLine( "     165; when a sample of the population of 15, a standard deviation  of" );
   streamWriter->WriteLine( "     5, and a mean of 168." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    claimedMean = 165" );
   streamWriter->WriteLine( "    mean = 168" );
   streamWriter->WriteLine( "    standardDeviation = 5" );
   streamWriter->WriteLine( "    sampleSize = 15" );
   streamWriter->WriteLine( "    significanceLevel = 95" );
   // Here we test the hypothesis that the mean.
   bool hypoMean1;
   {
   hypoMean1 = instanceOfNormalHypothesis->MeanTest( 
      165.0, // claimedMean
      168.0, // mean
      5.0, // standardDeviation
      15, // sampleSize
      95.0 // significanceLevel
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The statement that the null hypothesis is be rejected is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( hypoMean1 );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "       -------------------------------------------------------------------" );
   streamWriter->WriteLine( "       - Please scroll up to the top of the console to view the examples -" );
   streamWriter->WriteLine( "       -------------------------------------------------------------------" );
   streamWriter->WriteLine( " " );
   //
   myProcess->StandardInput->Close();
   myProcess->WaitForExit();
}

