#using <mscorlib.dll>

using namespace System;
using namespace System::ComponentModel;
using namespace System::Diagnostics;
using namespace System::IO;
using namespace WebCab::Lib::Util::Example;

using namespace WebCab::Libraries::Statistics::PDistributions;

template< class T >
T managed2DimArray( T* ca, int dim1, int dim2 ) __gc[,] {
   T a __gc[,] = new T __gc[dim1, dim2];
   for ( int i = 0; i < dim1; i ++ ) {
      for ( int j = 0; j < dim2; j ++ ) {
         a[i, j] = ca[ i * dim2 + j ];
      }
   }
   return a;
}

static double double2Double( double d ) {
   if ( Double::IsNaN( d ) ) return d;
   if ( Double::IsNegativeInfinity( d ) ) return d;
   if ( Double::IsPositiveInfinity( d ) ) return d;
   if ( d == Double::MinValue ) return d;
   if ( d == Double::MaxValue ) return d;
   double frac = d - ( int )d;
   double frac4 = ( int )( frac * 10000 ) / 10000.0;
   return ( int )d + frac4;
}

static void displayArray( double a __gc[], StreamWriter* streamWriter ) {
   for ( int i = 0; i < a->Length; i ++ ) {
      streamWriter->Write( double2Double( a[ i ] ) );
      streamWriter->Write( ", " );
   }
   streamWriter->WriteLine( " " );
}

int main() {
   Process* myProcess;
   myProcess = new Process ();
   myProcess->StartInfo->FileName = "more.com";
   myProcess->StartInfo->UseShellExecute = false;
   myProcess->StartInfo->RedirectStandardInput = true;
   myProcess->Start();
   StreamWriter* streamWriter = myProcess->StandardInput;
   streamWriter->AutoFlush = true;
   // used components
   WeibullProbabilityDistribution* instanceOfWeibullProbabilityDistribution = new WeibullProbabilityDistribution;
   //
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "            #########################################################" );
   streamWriter->WriteLine( "            # WeibullProbabilityDistribution Console Client Example #" );
   streamWriter->WriteLine( "            #########################################################" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " --------" );
   streamWriter->WriteLine( " Overview" );
   streamWriter->WriteLine( " --------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    Here we offer an example for each of the  public  methods  contained" );
   streamWriter->WriteLine( "    within the WeibullProbabilityDistribution." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Press ENTER or SPACE to scroll down." );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Setting the Shape +" );
   streamWriter->WriteLine( "+++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    setShape( double shape )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we set the Shape parameter to 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    shape = 5" );
   // Here we set the Shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The Shape parameter has now been set." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Get the Shape Parameter +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    getShape(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we get the Shape parameter which has just been set to 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we get the Shape parameter.
   double getShape1;
   {
   getShape1 = instanceOfWeibullProbabilityDistribution->GetShape( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The Shape parameter is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( getShape1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Setting the Location and Scale Parameters +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    setGeneral( double location," );
   streamWriter->WriteLine( "                double scale )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we set the location parameter to 2, and the scale parameter  to" );
   streamWriter->WriteLine( "     3, for the General Weibull probability distribution." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    location = 2" );
   streamWriter->WriteLine( "    scale = 3" );
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The location and scale parameter has now been set." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Getting the Location Parameter +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    getLocation(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we get the value of  the  location  parameter  of  the  General" );
   streamWriter->WriteLine( "     Weibull Probability Distribution which has just been set." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we get the location parameter.
   double getLocation1;
   {
   getLocation1 = instanceOfWeibullProbabilityDistribution->GetLocation( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the location parameter is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( getLocation1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Getting the Scale Parameter +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    getScale(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we get the value of the scale parameter of the General  Weibull" );
   streamWriter->WriteLine( "     Probability Distribution which has just been set." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we get the scale parameter.
   double getScale1;
   {
   getScale1 = instanceOfWeibullProbabilityDistribution->GetScale( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the scale parameter is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( getScale1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Evaluate the Probability Density  Function  of  the  Standard  Weibull +" );
   streamWriter->WriteLine( "+ Probability distribution                                               +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    probDensity( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the Probability Density  function  of  the  Weibull" );
   streamWriter->WriteLine( "     Probability Distribution at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we evaluate the  Probability  Density  function  of  the  Weibull
   // Probability Distribution set.
   double probDensity1;
   {
   probDensity1 = instanceOfWeibullProbabilityDistribution->ProbDensity( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Probability Density function at the point 1, is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( probDensity1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Evaluate the Probability  Density  Function  of  the  General  Weibull +" );
   streamWriter->WriteLine( "+ Probability distribution                                               +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    probDensityGen( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the Probability Density  function  of  the  General" );
   streamWriter->WriteLine( "     Weibull Probability Distribution which has been set at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we evaluate the  Probability  Density  function  of  the  General
   // Weibull Probability distribution which has been set.
   double probDensity2;
   {
   probDensity2 = instanceOfWeibullProbabilityDistribution->ProbDensityGen( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Probability Density function at the point 1, is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( probDensity2 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Cumulative Distribution +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    cumulativeDist( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here  we  evaluate  the  Cumulative  Distribution  function  of  the" );
   streamWriter->WriteLine( "     Weibull Probability distribution at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we evaluate the Cumulative Distribution function of  the  Weibull
   // Probability distribution.
   double cumDis1;
   {
   cumDis1 = instanceOfWeibullProbabilityDistribution->CumulativeDist( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Cumulative Distribution function at the point 1, is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( cumDis1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Cumulative Distribution General +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    cumulativeDistGen( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here  we  evaluate  the  Cumulative  Distribution  function  of  the" );
   streamWriter->WriteLine( "     General Weibull Probability distribution just set at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we evaluate the Cumulative Distribution function for the  General
   // Weibull Probability distribution set.
   double cumDisGen1;
   {
   cumDisGen1 = instanceOfWeibullProbabilityDistribution->CumulativeDistGen( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the cumulative probability distribution is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( cumDisGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++" );
   streamWriter->WriteLine( "+ Percent Point +" );
   streamWriter->WriteLine( "+++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percentPoint( double percent )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     We evaluated the Percent point function of the  Weibull  Probability" );
   streamWriter->WriteLine( "     function   at  50  percent  for  the  Standard  Weibull  Probability" );
   streamWriter->WriteLine( "     function set with shape parameter 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percent = 0.5" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here    we  evaluated  the  percent  point  function  of  the  Weibull
   // Probability Function set.
   double percent1;
   {
   percent1 = instanceOfWeibullProbabilityDistribution->PercentPoint( 
      0.5 // percent
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Percent Point function at 50 percent is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( percent1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Percent Point General +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percentPointGen( double percent )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Evaluate the value of the Percent Point  function  for  the  General" );
   streamWriter->WriteLine( "     Weibull Probability distribution at 50  percent,  where  the  shape," );
   streamWriter->WriteLine( "     location and scale parameters take the values 5, 2, 3 respectively." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percent = 0.5" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we evaluate  the  Percent  Point  from  of  the  General  Weibull
   // Probability function set.
   double percentGen1;
   {
   percentGen1 = instanceOfWeibullProbabilityDistribution->PercentPointGen( 
      0.5 // percent
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Percent Point function at 50 percent for the  General" );
   streamWriter->WriteLine( "    Weibull Probability function set is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( percentGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++" );
   streamWriter->WriteLine( "+ Hazard Function +" );
   streamWriter->WriteLine( "+++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    hazard( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Evaluate the Hazard function for the  Standard  Weibull  Probability" );
   streamWriter->WriteLine( "     function with a Shape Parameter of 5, at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Evaluate the Hazard function  for  the  Standard  Weibull  Probability
   // function with a Shape Parameter of 5, at the point 1.
   double hazard1;
   {
   hazard1 = instanceOfWeibullProbabilityDistribution->Hazard( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Hazard function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( hazard1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Hazard Function General +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    hazardGen( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Evaluate the Hazard function for  the  General  Weibull  Probability" );
   streamWriter->WriteLine( "     function at the  point  1,  where  the  shape,  location  and  scale" );
   streamWriter->WriteLine( "     parameters take the values 5, 2, 3 respectively." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Calculate the Hazard  function  of  the  General  Weibull  Probability
   // function set at 1.
   double hazardGen1;
   {
   hazardGen1 = instanceOfWeibullProbabilityDistribution->HazardGen( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Hazard function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( hazardGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Cumulative Hazard Function +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    cumulHazard( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Evaluate the Cumulative Hazard function for the Weibull  Probability" );
   streamWriter->WriteLine( "     Distribution with a shape parameter of 5, at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Evaluate the Cumulative Hazard function for  the  Weibull  Probability
   // Distribution with a shape parameter of 5, at the point 1.
   double cumulHazard1;
   {
   cumulHazard1 = instanceOfWeibullProbabilityDistribution->CumulHazard( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Cumulative Hazard Function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( cumulHazard1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Cumulative Hazard Function General +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    cumulHazardGen( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Evaluate the Cumulative Hazard  function  for  the  General  Weibull" );
   streamWriter->WriteLine( "     Probability Distribution at the point 1, where the  shape,  location" );
   streamWriter->WriteLine( "     and scale parameters are 5, 2, 3 respectively." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 5" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Evaluate the  Cumulative  Hazard  function  for  the  General  Weibull
   // Probability Distribution at the point 1,  where  the  shape,  location
   // and scale parameters are 5, 2, 3 respectively.
   double cumulativeHazardGen1;
   {
   cumulativeHazardGen1 = instanceOfWeibullProbabilityDistribution->CumulHazardGen( 
      5.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Cumulative Hazard function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( cumulativeHazardGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Survival Function +" );
   streamWriter->WriteLine( "+++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    survival( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the  Survival  Function  of  the  Standard  Weibull" );
   streamWriter->WriteLine( "     distribution with a shape parameter of 5, at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we evaluate the survival function at 1.
   double survival1;
   {
   survival1 = instanceOfWeibullProbabilityDistribution->Survival( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the survival function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( survival1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Survival Function General +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    survivalGen( double evaluationPoint )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate  the  Survival  Function  of  the  General  Weibull" );
   streamWriter->WriteLine( "     Probability distribution with shape, location and  scale  parameters" );
   streamWriter->WriteLine( "     of 5, 2, 3, respectively; at the point 1." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    evaluationPoint = 1" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here  we  evaluate  the  Survival  Function  of  the  General  Weibull
   // distribution wich has just been set.
   double survivalGen1;
   {
   survivalGen1 = instanceOfWeibullProbabilityDistribution->SurvivalGen( 
      1.0 // evaluationPoint
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Survival Function is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( survivalGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Inverse Survival Function +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    inverseSurvival( double percent )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     We evaluate the Inverse Survival Function for the Standard  Survival" );
   streamWriter->WriteLine( "     function at the 50 percent level." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percent = 0.50" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we evaluate the Inverse  Survival  function  at  the  50  percent
   // level.
   double inverseSurvival1;
   {
   inverseSurvival1 = instanceOfWeibullProbabilityDistribution->InverseSurvival( 
      0.50 // percent
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Inverse Survival function at  the  50  percent  level" );
   streamWriter->WriteLine( "    is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( inverseSurvival1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Inverse Survival Function General +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    inverseSurvivalGen( double percent )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the Inverse Survival function of a General  Weibull" );
   streamWriter->WriteLine( "     Probability distribution at the 50 percent level, where  the  shape," );
   streamWriter->WriteLine( "     location and scale parameters at 5, 2, 3, respectively." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    percent = 0.50" );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we set the location and scale parameters

   {
   instanceOfWeibullProbabilityDistribution->SetGeneral( 
      2.0, // location
      3.0 // scale
   );
   }
   // Here we evaluate the Inverse Survival function of  a  General  Weibull
   // Probability distribution at the 50 percent level.
   double inverseSurvivalGen1;
   {
   inverseSurvivalGen1 = instanceOfWeibullProbabilityDistribution->InverseSurvivalGen( 
      0.50 // percent
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The value of the Inverse Survival function are:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( inverseSurvivalGen1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Mean of Standard Weibull Probability distribution +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    mean(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate  the  mean  of  the  Standard  Weibull  Probability" );
   streamWriter->WriteLine( "     distribution with a shape parameter of 5:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here  we  evaluate  the  mean  of  the  Standard  Weibull  Probability
   // distribution.
   double mean1;
   {
   mean1 = instanceOfWeibullProbabilityDistribution->Mean( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The mean of the Standard Weibull Distribution is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( mean1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Median of the Standard Weibull Probability Distribution +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    median(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the median  of  the  Standard  Weibull  Probability" );
   streamWriter->WriteLine( "     Distribution where a shape parameter of 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we evaluate the median of the Weibull Probability Distribution.
   double median1;
   {
   median1 = instanceOfWeibullProbabilityDistribution->Median( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The median of the Weibull distribution is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( median1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Mode of the Standard Weibull Probability Distribution +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    mode(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate  the  mode  of  the  Standard  Weibull  Probability" );
   streamWriter->WriteLine( "     distribution with a shape parameter of 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here  we  evaluate  the  mode  of  the  Standard  Weibull  Probability
   // distribution.
   double mode1;
   {
   mode1 = instanceOfWeibullProbabilityDistribution->Mode( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The mode of the Weibull probability distribution is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( mode1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Standard Deviation of the Weibull Distribution +" );
   streamWriter->WriteLine( "++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    standardDeviation(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we evaluate the standard deviation of the Weibull  Distribution" );
   streamWriter->WriteLine( "     when the shape parameter is 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here we evaluate the standard deviation of the Weibull distribution.
   double standDev1;
   {
   standDev1 = instanceOfWeibullProbabilityDistribution->StandardDeviation( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The standard deviation of the Weibull distribution is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( standDev1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( "+ Coefficient of Variation of the SWeibull Distribution +" );
   streamWriter->WriteLine( "+++++++++++++++++++++++++++++++++++++++++++++++++++++++++" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " Within this example we test the following method:" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    coeffVariation(  )" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " Question:" );
   streamWriter->WriteLine( " ---------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "     Here we  evaluate  the  coefficient  of  variation  of  the  Weibull" );
   streamWriter->WriteLine( "     Distribution with a shape parameter of 5." );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " Parameter values required to solve this problem:" );
   streamWriter->WriteLine( " ------------------------------------------------" );
   streamWriter->WriteLine( " " );
   // Here we set the shape parameter.

   {
   instanceOfWeibullProbabilityDistribution->SetShape( 
      5.0 // shape
   );
   }
   // Here  we  evaluated  the  coefficient  of  variation  of  the  WEibull
   // distribution.
   double coeffOfVariation1;
   {
   coeffOfVariation1 = instanceOfWeibullProbabilityDistribution->CoeffVariation( 
   );
   }
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " Answer evaluated:" );
   streamWriter->WriteLine( " -----------------" );
   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "    The coefficient of variation is:" );
   streamWriter->WriteLine( " " );
   streamWriter->Write( "    " );
   streamWriter->WriteLine( double2Double( coeffOfVariation1 ) );
   streamWriter->WriteLine( " " );

   streamWriter->WriteLine( " " );
   streamWriter->WriteLine( "       -------------------------------------------------------------------" );
   streamWriter->WriteLine( "       - Please scroll up to the top of the console to view the examples -" );
   streamWriter->WriteLine( "       -------------------------------------------------------------------" );
   streamWriter->WriteLine( " " );
   //
   myProcess->StandardInput->Close();
   myProcess->WaitForExit();
}

